IntoStableEncoding

Trait IntoStableEncoding 

pub trait IntoStableEncoding {
    // Required method
    fn into_stable_encoding(self) -> StableOsString;
}
Converts an OsString from an encoding that is stable across rust compiler versions, bypassing data copies if possible

Required Methods

fn into_stable_encoding(self) -> StableOsString

Converts an OsString from an encoding that is stable across rust compiler versions, bypassing data copies if possible

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoStableEncoding for OsString

Implementors