pub trait ToStableEncoding {
// Required method
fn to_stable_encoding(&self) -> StableOsString;
}Expand description
Converts an OsString or OsStr to an encoding that is stable across rust compiler versions
Required Methods
Sourcefn to_stable_encoding(&self) -> StableOsString
fn to_stable_encoding(&self) -> StableOsString
Converts an OsString or OsStr to an encoding that is stable across rust compiler versions
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".