pub trait FromStableEncoding {
// Required method
fn from_stable_encoding<'a>(
encoded: impl Into<Cow<'a, [EncodingWidth]>>,
) -> Self;
}Expand description
Converts an OsString from an encoding that is stable across rust compiler versions, bypassing data copies if possible
Required Methods
Sourcefn from_stable_encoding<'a>(
encoded: impl Into<Cow<'a, [EncodingWidth]>>,
) -> Self
fn from_stable_encoding<'a>( encoded: impl Into<Cow<'a, [EncodingWidth]>>, ) -> Self
Converts an OsString from an encoding that is stable across rust compiler versions, bypassing data copies if possible
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".