pub trait IntoStableEncoding {
// Required method
fn into_stable_encoding(self) -> StableOsString;
}Expand description
Converts an OsString from an encoding that is stable across rust compiler versions, bypassing data copies if possible
Required Methods
Sourcefn into_stable_encoding(self) -> StableOsString
fn into_stable_encoding(self) -> StableOsString
Converts an OsString from an encoding that is stable across rust compiler versions, bypassing data copies if possible
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".