ToStableEncoding

Trait ToStableEncoding 

pub trait ToStableEncoding {
    // Required method
    fn to_stable_encoding(&self) -> StableOsString;
}
Converts an OsString or OsStr to an encoding that is stable across rust compiler versions

Required Methods

fn to_stable_encoding(&self) -> StableOsString

Converts an OsString or OsStr to an encoding that is stable across rust compiler versions

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToStableEncoding for OsStr

Source

impl ToStableEncoding for OsString

Implementors